<html>
<head>
    <link href="https://v4-alpha.getbootstrap.com/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
    body {
      padding-top: 2rem;
      padding-bottom: 2rem;
    }
    h3, h4, h5 {
        padding: 2rem 0 0.5rem 0;
    }
    .table ul {
        padding-left: 0;
        margin-bottom: 0;
        list-style-type: none;
    }
    </style>
</head>
<body>
    <div class="container">
    {% block content %}
    {% endblock %}
    </div>
</body>
</html>
